diff --git a/src/routes/console/(billing-modal)/postReleaseModal.svelte b/src/routes/console/(billing-modal)/postReleaseModal.svelte
index ee51e7b17..c303698cf 100644
--- a/src/routes/console/(billing-modal)/postReleaseModal.svelte
+++ b/src/routes/console/(billing-modal)/postReleaseModal.svelte
@@ -37,11 +37,11 @@
});
}
- $: isNewUser = new Date($user.$createdAt) > new Date(2023, 11, 18);
- //user creation date after the 18th of December 2023
+ $: isNewUser = new Date($user.$createdAt) > new Date(2023, 11, 19);
+ //user creation date after the 19th of December 2023
$: event = isNewUser ? 'billing_new_user_modal' : 'billing_release_modal';
- $: freeOrgs = orgs?.teams.filter((o) => o.billingPlan === 'tier-0');
- $: options = freeOrgs.map((o) => ({ label: o.name, value: o.$id }));
+ $: freeOrgs = orgs?.teams?.filter((o) => o.billingPlan === 'tier-0');
+ $: options = freeOrgs?.map((o) => ({ label: o.name, value: o.$id }));